﻿using System;
using System.Drawing;
using System.Windows.Forms;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 이벤트를 설정한다.

            Load       += Form_Load;
            MouseClick += Form_MouseClick;

            #endregion
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private
        //////////////////////////////////////////////////////////////////////////////// Event

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            const int width  = 63;
            const int height = 63;

            Bitmap bitmap = new Bitmap(width, height);

            using(Graphics graphics = Graphics.FromImage(bitmap))
            {
                graphics.Clear(Color.Transparent);

                int centerX = width  / 2;
                int centerY = height / 2;

                Point[] outerPointArray =
                {
                    new Point(centerX, 0),
                    new Point(2 * centerX, centerY),
                    new Point(centerX, 2 * centerY),
                    new Point(0, centerY),
                };

                using(SolidBrush brush = new SolidBrush(Color.FromArgb(128, 255, 255, 0)))
                {
                    graphics.FillPolygon(brush, outerPointArray);
                }

                graphics.DrawPolygon(Pens.Red, outerPointArray);

                Point[] innerPointArray =
                {
                    new Point(centerX    , centerY - 6),
                    new Point(centerX + 6, centerY    ),
                    new Point(centerX    , centerY + 6),
                    new Point(centerX - 6, centerY    )
                };

                graphics.FillPolygon(Brushes.LightBlue, innerPointArray);

                graphics.DrawPolygon(Pens.Blue, innerPointArray);
            }

            Cursor = new Cursor(bitmap.GetHicon());
        }

        #endregion
        #region 폼 마우스 클릭시 처리하기 - Form_MouseClick(sender, e)

        /// <summary>
        /// 폼 마우스 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_MouseClick(object sender, MouseEventArgs e)
        {
            this.messageLabel.Text = "(" + e.X.ToString() + ", " + e.Y.ToString() + ")";
        }

        #endregion
    }
}